@@ -6,6 +6,8 @@
 
 from .application_tags import ApplicationTags
 from .heartbeater_service import HeartbeaterService
+from .utils import event_to_json
+from .utils import event_to_line_data
 from .utils import histogram_to_line_data
 from .utils import metric_to_line_data
 from .utils import tracing_span_to_line_data
@@ -13,5 +15,7 @@ from .utils import tracing_span_to_line_data
 __all__ = ['histogram_to_line_data',
            'metric_to_line_data',
            'tracing_span_to_line_data',
+           'event_to_json',
+           'event_to_line_data',
            'ApplicationTags',
            'HeartbeaterService']
