@@ -26,7 +26,7 @@ class ProxyConnectionHandler(connection_handler.ConnectionHandler):
         @param address: Proxy Address
         @param port: Proxy Port
         """
-        super(ProxyConnectionHandler, self).__init__()
+        super().__init__()
         self._address = address
         self._port = int(port)
         self.entity_prefix = '' if not entity_prefix else entity_prefix + ''
