@@ -4,6 +4,7 @@
 @author Hao Song (songhao@vmware.com)
 """
 
+from .event.sender import WavefrontEventSender
 from .histogram import histogram_granularity
 from .histogram.histogram_impl import WavefrontHistogramImpl
 from .histogram.sender import WavefrontHistogramSender
@@ -15,4 +16,5 @@ __all__ = ['histogram_granularity',
            'WavefrontHistogramImpl',
            'WavefrontHistogramSender',
            'WavefrontMetricSender',
+           'WavefrontEventSender',
            'WavefrontTracingSpanSender']
