@@ -1,7 +1,5 @@
 # -*- coding: utf-8 -*-
-
-"""
-Tracing Span Entities.
+"""Tracing Span Entities.
 
 @author Hao Song (songhao@vmware.com)
 """
